pub fn get_weather_state(block: BlockRef) -> Option<WeatherState>Expand description
Returns the weathering state of a copper block, or None if it’s not a weathering block.
pub fn get_weather_state(block: BlockRef) -> Option<WeatherState>Returns the weathering state of a copper block, or None if it’s not a weathering block.